**To reboot an Amazon EC2 instance**

This example reboots the specified instance. If the command succeeds, no output is returned.

Command::

  aws ec2 reboot-instances --instance-ids i-1234567890abcdef5

For more information, see `Reboot Your Instance`_ in the *Amazon Elastic Compute Cloud User Guide*.

.. _`Reboot Your Instance`: http://docs.aws.amazon.com/AWSEC2/latest/UserGuide/ec2-instance-reboot.html

